@@ -70,7 +70,10 @@ def fetch_2d_pose_data_alphapose_local_time_segment(
             )
             frame_number = int(m.group('frame_number_string'))
             with open(path, 'r') as fp:
-                pose_data_object = json.load(fp)
+                try:
+                    pose_data_object = json.load(fp)
+                except:
+                    raise ValueError('Error reading JSON from file {}'.format(path))
             if len(pose_data_object) == 0:
                 continue
             timestamp_json_string = pose_data_object.get('timestamp')
@@ -139,7 +142,10 @@ def fetch_2d_pose_data_alphapose_local_time_segment(
                 tzinfo=datetime.timezone.utc
             )
             with open(path, 'r') as fp:
-                pose_data_object = json.load(fp)
+                try:
+                    pose_data_object = json.load(fp)
+                except:
+                    raise ValueError('Error reading JSON from file {}'.format(path))
             if len(pose_data_object) == 0:
                 continue
             if json_format == 'cmu':
@@ -876,6 +882,9 @@ def generate_time_segment_start_list(
         second=10*(start_utc.second // 10),
         tzinfo=start_utc.tzinfo
     )
-    num_time_segments = math.ceil((end_utc - start_utc_floor).total_seconds()  / 10.0)
+    if end_utc == start_utc_floor:
+        num_time_segments = 1
+    else:
+        num_time_segments = math.ceil((end_utc - start_utc_floor).total_seconds()  / 10.0)
     time_segment_start_list = [start_utc_floor + i*datetime.timedelta(seconds=10) for i in range(num_time_segments)]
     return time_segment_start_list
