@@ -1,4 +1,4 @@
-import process_pose_data.honeycomb_io
+import honeycomb_io
 import cv_utils
 import cv2 as cv
 import pandas as pd
@@ -35,7 +35,7 @@ def keypoint_quality_histogram_by_camera(
     if display_camera_name:
         if camera_names is None:
             camera_ids = df['camera_id'].unique().tolist()
-            camera_names = process_pose_data.honeycomb_io.fetch_camera_names(camera_ids)
+            camera_names = honeycomb_io.fetch_camera_names(camera_ids)
     for camera_id, group_df in df.groupby('camera_id'):
         if display_camera_name:
             camera_id_string = camera_names.get(camera_id)
@@ -139,7 +139,7 @@ def num_valid_keypoints_histogram_by_camera(
     if display_camera_name:
         if camera_names is None:
             camera_ids = df['camera_id'].unique().tolist()
-            camera_names = process_pose_data.honeycomb_io.fetch_camera_names(camera_ids)
+            camera_names = honeycomb_io.fetch_camera_names(camera_ids)
     for camera_id, group_df in df.groupby('camera_id'):
         if display_camera_name:
             camera_id_string = camera_names.get(camera_id)
@@ -245,7 +245,7 @@ def pose_quality_histogram_by_camera(
     if display_camera_name:
         if camera_names is None:
             camera_ids = df['camera_id'].unique().tolist()
-            camera_names = process_pose_data.honeycomb_io.fetch_camera_names(camera_ids)
+            camera_names = honeycomb_io.fetch_camera_names(camera_ids)
     for camera_id, group_df in df.groupby('camera_id'):
         if display_camera_name:
             camera_id_string = camera_names.get(camera_id)
@@ -349,7 +349,7 @@ def mean_keypoint_quality_histogram_by_camera(
     if display_camera_name:
         if camera_names is None:
             camera_ids = df['camera_id'].unique().tolist()
-            camera_names = process_pose_data.honeycomb_io.fetch_camera_names(camera_ids)
+            camera_names = honeycomb_io.fetch_camera_names(camera_ids)
     for camera_id, group_df in df.groupby('camera_id'):
         if display_camera_name:
             camera_id_string = camera_names.get(camera_id)
@@ -452,7 +452,7 @@ def mean_keypoint_quality_pose_quality_scatter_by_camera(
     if display_camera_name:
         if camera_names is None:
             camera_ids = df['camera_id'].unique().tolist()
-            camera_names = process_pose_data.honeycomb_io.fetch_camera_names(camera_ids)
+            camera_names = honeycomb_io.fetch_camera_names(camera_ids)
     for camera_id, group_df in df.groupby('camera_id'):
         if display_camera_name:
             camera_id_string = camera_names.get(camera_id)
@@ -636,7 +636,7 @@ def pose_pair_score_heatmap_timestamp_camera_pair(
     if display_camera_names:
         if camera_names is None:
             camera_ids = [camera_id_a, camera_id_b]
-            camera_names = process_pose_data.honeycomb_io.fetch_camera_names(camera_ids)
+            camera_names = honeycomb_io.fetch_camera_names(camera_ids)
     if plot_title is not None:
         ax_title = '{} ({})'.format(
             plot_title,
@@ -850,7 +850,7 @@ def pose_track_3d_timelines_by_camera(
     if display_camera_name:
         if camera_names is None:
             camera_ids = df['camera_id'].unique().tolist()
-            camera_names = process_pose_data.honeycomb_io.fetch_camera_names(camera_ids)
+            camera_names = honeycomb_io.fetch_camera_names(camera_ids)
     for camera_id, group_df in df.groupby('camera_id'):
         if display_camera_name:
             camera_id_string = camera_names.get(camera_id)
